@@ -392,9 +392,11 @@ def indexacion(df,mini,maxi):
         years2.append(maxi)
     conditionlist1=[]
     conditionlist2=[]
-    for k in range(0,(len(years1))-1): 
+    for k in range(0,(len(years1))-2): 
         c=(df['antiguedad'] >=years1[k]) & (df['antiguedad'] <years1[k+1])
         conditionlist1.append(c)
+    c=(df['antiguedad'] >=years1[(len(years1))-2]) & (df['antiguedad'] <=years1[(len(years1))-1])
+    conditionlist1.append(c)
     L=["A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","W","X","Y","Z"]
     vectorS1=[]
     vectorS2=[]
@@ -405,9 +407,11 @@ def indexacion(df,mini,maxi):
     for i in range(0,len(vectorS1)):
         choicelist1.append(vectorS1[i][0]+vectorS1[i][3:6]+vectorS1[i][8:10])
     
-    for k in range(0,(len(years2))-1): 
+    for k in range(0,(len(years2))-2): 
         c2=(df['antiguedad'] >=years2[k]) & (df['antiguedad'] <years2[k+1])
         conditionlist2.append(c2)
+    c2=(df['antiguedad'] >=years2[(len(years2))-2]) & (df['antiguedad'] <=years2[(len(years2))-1])
+    conditionlist2.append(c2)
     for i in range(0,len(years2)-2):
         vectorS2.append(L[i]+str(years2[i])+"/"+str(years2[i+1]-1))
     vectorS2.append(L[len(years2)-2]+str(years2[len(years2)-2])+"/"+str(years2[len(years2)-1]))    
